HRBelowPlannedWorkoutStepDuration class
- Inheritance
-
- Object
- PlannedWorkoutStepDuration
- HRBelowPlannedWorkoutStepDuration
Constructors
- HRBelowPlannedWorkoutStepDuration({PlannedWorkoutStepDurationType durationType = PlannedWorkoutStepDurationType.hrLessThan, int? hrBelowBpm})
-
HRBelowPlannedWorkoutStepDuration.fromJson(Map<
String, dynamic> json) -
factory
- HRBelowPlannedWorkoutStepDuration.fromValue({required int durationType, int? hrBelowBpm})
Properties
- durationType ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hrBelowBpm ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited